#ifndef DIRECT_WHEEL_CTRL_H
#define DIRECT_WHEEL_CTRL_H

/*!
  \file
  \brief ԗւ̒ړIȉ]x

  \author Satofumi KAMIMURA

  $Id$
*/

#include "wheelCtrl.h"


/*!
  \brief ԗւ̒ڐ̏Ǘ
*/
typedef struct {
  int ref_mm_sec_vel;
} directWheelInfo_t;


//#include "cpp_extern_macro.h"
BEGIN_C_DECLS;

extern void initDirectWheelCtrlInfo(directWheelInfo_t *directWhl);

END_C_DECLS;
#endif /* !DIRECT_WHEEL_CTRL_H */
